@@ -1,19 +1,25 @@
+from __future__ import annotations
+
+
 class Point:
     """
     Creates an elementary point.
 
-    x : array-like[3]
-        Give the three X, Y and Z coordinates of the
-        point in the three-dimensional Euclidean space.
-    mesh_size : float
-        The prescribed mesh element size at this point.
+    x : Give the coordinates X, Y (and Z) of the point in the three-dimensional
+        Euclidean space.
+    mesh_size : The prescribed mesh element size at this point.
     """
 
     dim = 0
 
-    def __init__(self, env, x, mesh_size=None):
+    def __init__(
+        self,
+        env,
+        x: tuple[float, float] | tuple[float, float, float],
+        mesh_size: float | None = None,
+    ):
         if len(x) == 2:
-            x = [x[0], x[1], 0.0]
+            x = (x[0], x[1], 0.0)
 
         assert len(x) == 3
         self.x = x
